#
# spec file for package giada
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2015 Packman Team <packman@links2linux.de>
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           giada
Version:        0.15.0
Release:        1.1
Summary:        Sampler Audio Tool
License:        GPL-3.0-or-later
Group:          Productivity/Multimedia/Sound/Utilities
URL:            https://giadamusic.com
Source0:        https://github.com/monocasual/giada/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        giada.svg
Source2:        %{name}.changes
# PATCH-FIX-OPENSUSE giada-gcc48.patch fix compilation with gcc 4.8 -- aloisio@gmx.com
Patch0:         %{name}-gcc48.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  fltk-devel
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  portaudio-devel
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(jansson) >= 2.7
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libpulse-simple)
BuildRequires:  pkgconfig(rtmidi) >= 2.1.0
BuildRequires:  pkgconfig(samplerate)
BuildRequires:  pkgconfig(sndfile)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xft)
BuildRequires:  pkgconfig(xpm)

%description
Giada is an audio tool for DJs and live performers. Up to 32 samples
may be loaded or recorded, and may be played in single mode (drum
machine) or loop mode (sequencer). The keyboard can be used to
control this.

%prep
%setup -q
# Do not compile in DATE and TIME
BUILDDATE=$(LC_ALL=C date -ur %{_sourcedir}/%{name}.changes +'%{b} %{d} %{Y}')
sed -i "s/__DATE__/\"$BUILDDATE\"/" $(grep -rl '__DATE__') || :
%patch0 -p1

%build
./autogen.sh
%configure --target=linux
make %{?_smp_mflags}

%install
%make_install

install -Dm 0644 %{SOURCE1} %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%suse_update_desktop_file -c %{name} %{name} "Sampler Audio Tool" %{name} %{name} AudioVideo Audio Sequencer

%if 0%{?suse_version} < 1500
%post
%icon_theme_cache_post
%desktop_database_post

%postun
%icon_theme_cache_postun
%desktop_database_postun
%endif

%files
%doc ChangeLog
%license COPYING
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg

%changelog
* Sat Apr 21 2018 jengelh@inai.de
- Ensure neutrality of description.
* Thu Apr 19 2018 aloisio@gmx.com
- Update to version 0.15.0
  * Refactor audio engine into frame-based processing
  * Refactor channels readers/writers into channelManager namespace
  * Smarter Solo algorithm
  * Fix missing .wav extension on recorded audio takes
  * Fix wrong Channel status update after 'Clear all actions'
  version 0.14.6
  * MIDI velocity drives volume for one-shot sample channels
  * FLAC and Ogg support
  * Ability to use system-provided Catch library (GitHub #151)
  * Update Catch to version 2
  * Fix unreadable tabs title in Configuration Window (GitHub #168)
  * Fix crash on opening About window
  * Fix 'read actions' button behavior during ending and waiting statuses
  version 0.14.5
  * Support for multiple plug-in directories
  * New directory browser for adding plug-in directories
  * Update plug-in's parameters on program change in plug-in's window
  * Improved MIDI action management in Piano Roll
  * Simplified conditional rules in Makefile.am
  * Fix crash on MIDI learn for plug-in parameters
  * Fix crash in MIDI input window if MIDI in params are 0
  * Fix unwanted new action when dragging piano items in Piano Roll
  * Fix crash while recording on existing project (GitHub #161)
- Dropped giada.patch (no longer necessary)
- Added giada-gcc48.patch
- Spec cleanup
* Fri Oct 27 2017 avvissu@yandex.by
- Update to 0.14.4:
  * see: /usr/share/doc/packages/giada/ChangeLog
* Fri Oct  6 2017 avvissu@yandex.by
- Update to 0.14.3:
  * see: /usr/share/doc/packages/giada/ChangeLog
* Tue Aug 29 2017 avvissu@yandex.by
- Update to 0.14.2:
  * see: /usr/share/doc/packages/giada/ChangeLog
* Fri Jul 21 2017 avvissu@yandex.by
- Update to 0.14.1:
  * see: /usr/share/doc/packages/giada/ChangeLog
* Thu May 25 2017 avvissu@yandex.by
- Update to 0.13.4:
  * see: /usr/share/doc/packages/giada/ChangeLog
* Sat Oct 22 2016 avvissu@yandex.by
- Update to 0.13.0:
  * see: /usr/share/doc/packages/giada/ChangeLog
- Fix compilation errors on GCC 6
* Fri Jun 17 2016 avvissu@yandex.by
- Update to 0.12.2:
  * see: /usr/share/doc/packages/giada/ChangeLog
- Fix build on openSUSE > 13.2 (use a supported version of GCC)
* Wed Jan 27 2016 avvissu@yandex.ru
- Update to 0.11.2:
  * see: /usr/share/doc/packages/giada/ChangeLog
* Fri Dec 25 2015 avvissu@yandex.ru
- Update to 0.11.1:
  * see: /usr/share/doc/packages/giada/ChangeLog
* Sun Dec  6 2015 avvissu@yandex.ru
- Update to 0.11.0:
  * see: /usr/share/doc/packages/giada/ChangeLog
- Add BuildRequires: pkgconfig(jansson)
* Wed Oct 21 2015 avvissu@yandex.ru
- Update to 0.10.2:
  * see: /usr/share/doc/packages/giada/ChangeLog
* Sat Sep  5 2015 avvissu@yandex.ru
- Update to 0.10.1:
  * see: /usr/share/doc/packages/giada/ChangeLog
- Del -Wno-parentheses to build with gcc5 (fixed in upstream)
* Mon Jul 20 2015 avvissu@yandex.ru
- Update to 0.10.0:
  * MIDI lightning output
  * other minor fixes
* Thu Jun 25 2015 avvissu@yandex.ru
- Update to 0.9.6:
  * see: /usr/share/doc/packages/giada/ChangeLog
- Remove patches:
  * giada-remove_build_timestamps.patch (use sed)
  * giada-add_missing_link_to_Xinerama.patch (fix to upstream)
- Add new package: rtmidi-devel libpulse-devel
- Build with gcc5: disable check:-Wno-parentheses
- Fix files is compiled without RPM_OPT_FLAGS
- Remove giada.desktop: use %%%%suse_update_desktop_file
- Add %%%%icon_theme_cache_(post,postun)
- Spec file cleanup
* Tue May 29 2012 pascal.bleser@opensuse.org
- update to 0.4.10:
  - Ability to shift up an down VST plugins
  - Enhanced patch/conf architecture
  - Ability to edit a sample while playing
  - Mutex controls in VST processing
  - Lots of security issues fixed while changing pitch dynamically
  - Enhanced sub-window system
  - Several minor bugs fixed
- changes from 0.4.9:
  - No more mandatory inputs
  - Pitch value properly stored inside the patch
  - Several small VST host improvements
  - Enhanced window management
  - Ability to browse files while playing with main GUI (non-modal browser)
  - Improved error checking in KernelAudio
  - Wrong style for lower scrollbar in Browser (fixed)
  - Fixed compilation on 64 bit systems
  - Samplerate no longer hardcoded, auto-detected with JACK
  - Minor internal improvements and bugfixing
* Sat Apr 21 2012 pascal.bleser@opensuse.org
- initial version (0.4.8)
